# Code of Conduct

## Our Pledge

We pledge to make participation in our project a harassment-free experience for everyone.

## Our Standards

**Positive behavior includes:**
- Using welcoming and inclusive language
- Being respectful of differing viewpoints
- Gracefully accepting constructive criticism
- Focusing on what is best for the community

**Unacceptable behavior includes:**
- Trolling, insulting comments, and personal attacks
- Public or private harassment
- Publishing others' private information without permission

## Enforcement

Project maintainers may remove, edit, or reject contributions that violate this Code of Conduct.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.0.
